.. figure:: https://raw.githubusercontent.com/DevconX/Malaya/master/session/towns-of-malaya.jpg

|Downloads| |Latest Version| |Build Status| |Documentation Status|

.. |Downloads| image:: https://img.shields.io/pypi/dm/malaya.svg
   :target: https://pypi.python.org/pypi/malaya
.. |Latest Version| image:: https://badge.fury.io/py/malaya.svg
   :target: https://pypi.python.org/pypi/malaya
.. |Build Status| image:: https://travis-ci.org/huseinzol05/Malaya.svg?branch=master
   :target: https://travis-ci.org/huseinzol05/Malaya
.. |Documentation Status| image:: https://readthedocs.org/projects/malaya/badge/?version=latest
   :target: https://malaya.readthedocs.io/

Natural-Language-Toolkit for bahasa Malaysia, powered by Deep Learning
Tensorflow.

-  Free software: MIT license
-  Documentation: https://malaya.readthedocs.io/

Features
--------

-  **Entities Recognition**, using latest state-of-art CRF deep learning
   models to do Naming Entity Recognition.
-  **Language Detection**, using various machine learning models to distinguish Malay, English, and Indonesian.
-  **Normalizer**, using local Malaysia NLP researches to normalize any
   bahasa texts.
-  Num2Word
-  **Part-of-Speech Recognition**, using latest state-of-art CRF deep
   learning models to do POS Recognition.
-  **Sentiment Analysis**, from BERT, Fast-Text, Dynamic-Memory Network,
   Attention to build deep sentiment analysis models.
-  **Spell Correction**, using local Malaysia NLP researches to
   auto-correct any bahasa words.
-  Stemmer
-  **Summarization**, using skip-thought state-of-art to give precise
   summarization.
-  **Topic Modelling**, provide LDA2Vec, LDA, NMF and LSA interface for easy topic modelling.
-  **Topic and Influencers Analysis**, using deep and machine learning
   models to understand topics and Influencers similarity in sentences.
-  **Toxicity Analysis**, from BERT, Fast-Text, Dynamic-Memory Network,
   Attention to build deep Toxic Multi-label analysis models.
-  Word2Vec

Contributors
------------

-  **Husein Zolkepli** - *Initial work* - `huseinzol05`_

-  **Sani** - *build PIP package* - `khursani8`_

.. _Malaya Wiki: https://github.com/DevconX/Malaya/wiki
.. _huseinzol05: https://github.com/huseinzol05
.. _khursani8: https://github.com/khursani8
